This library/package will give all the info (colors of the pixels) of any image you choose

It has only one function called do()
syntax is like this do(r'Path\to\image',boolean) # the boolean is 'True' 'False' this is optional.
the boolean value determines weather color output is in rgb or hsv. True for rgb (default), False for hsv

My website: https://chaoticcoder.netlify.app